==> openshift-model-operator-6.2.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/OVNKubernetesConfigFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface OVNKubernetesConfigFluent<A extends OVNKubernetesConfigFluent<A>> extends Fluent<A>{
  public Integer getGenevePort();
  public A withGenevePort(Integer genevePort);
  public Boolean hasGenevePort();
  
  /**
   * This method has been deprecated, please use method buildHybridOverlayConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public HybridOverlayConfig getHybridOverlayConfig();
  public HybridOverlayConfig buildHybridOverlayConfig();
  public A withHybridOverlayConfig(HybridOverlayConfig hybridOverlayConfig);
  public Boolean hasHybridOverlayConfig();
  public OVNKubernetesConfigFluent.HybridOverlayConfigNested<A> withNewHybridOverlayConfig();
  public OVNKubernetesConfigFluent.HybridOverlayConfigNested<A> withNewHybridOverlayConfigLike(HybridOverlayConfig item);
  public OVNKubernetesConfigFluent.HybridOverlayConfigNested<A> editHybridOverlayConfig();
  public OVNKubernetesConfigFluent.HybridOverlayConfigNested<A> editOrNewHybridOverlayConfig();
  public OVNKubernetesConfigFluent.HybridOverlayConfigNested<A> editOrNewHybridOverlayConfigLike(HybridOverlayConfig item);
  
  /**
   * This method has been deprecated, please use method buildIpsecConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public IPsecConfig getIpsecConfig();
  public IPsecConfig buildIpsecConfig();
  public A withIpsecConfig(IPsecConfig ipsecConfig);
  public Boolean hasIpsecConfig();
  public OVNKubernetesConfigFluent.IpsecConfigNested<A> withNewIpsecConfig();
  public OVNKubernetesConfigFluent.IpsecConfigNested<A> withNewIpsecConfigLike(IPsecConfig item);
  public OVNKubernetesConfigFluent.IpsecConfigNested<A> editIpsecConfig();
  public OVNKubernetesConfigFluent.IpsecConfigNested<A> editOrNewIpsecConfig();
  public OVNKubernetesConfigFluent.IpsecConfigNested<A> editOrNewIpsecConfigLike(IPsecConfig item);
  public Integer getMtu();
  public A withMtu(Integer mtu);
  public Boolean hasMtu();
  
  /**
   * This method has been deprecated, please use method buildPolicyAuditConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public PolicyAuditConfig getPolicyAuditConfig();
  public PolicyAuditConfig buildPolicyAuditConfig();
  public A withPolicyAuditConfig(PolicyAuditConfig policyAuditConfig);
  public Boolean hasPolicyAuditConfig();
  public A withNewPolicyAuditConfig(String destination,Integer maxFileSize,Integer rateLimit,String syslogFacility);
  public OVNKubernetesConfigFluent.PolicyAuditConfigNested<A> withNewPolicyAuditConfig();
  public OVNKubernetesConfigFluent.PolicyAuditConfigNested<A> withNewPolicyAuditConfigLike(PolicyAuditConfig item);
  public OVNKubernetesConfigFluent.PolicyAuditConfigNested<A> editPolicyAuditConfig();
  public OVNKubernetesConfigFluent.PolicyAuditConfigNested<A> editOrNewPolicyAuditConfig();
  public OVNKubernetesConfigFluent.PolicyAuditConfigNested<A> editOrNewPolicyAuditConfigLike(PolicyAuditConfig item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface HybridOverlayConfigNested<N> extends Nested<N>,HybridOverlayConfigFluent<OVNKubernetesConfigFluent.HybridOverlayConfigNested<N>>{
    public N and();
    public N endHybridOverlayConfig();
    
  }
  public interface IpsecConfigNested<N> extends Nested<N>,IPsecConfigFluent<OVNKubernetesConfigFluent.IpsecConfigNested<N>>{
    public N and();
    public N endIpsecConfig();
    
  }
  public interface PolicyAuditConfigNested<N> extends Nested<N>,PolicyAuditConfigFluent<OVNKubernetesConfigFluent.PolicyAuditConfigNested<N>>{
    public N and();
    public N endPolicyAuditConfig();
    
  }
  
}

==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/OVNKubernetesConfigFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface OVNKubernetesConfigFluent<A extends OVNKubernetesConfigFluent<A>> extends Fluent<A>{
  public Integer getGenevePort();
  public A withGenevePort(Integer genevePort);
  public Boolean hasGenevePort();
  
  /**
   * This method has been deprecated, please use method buildHybridOverlayConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public HybridOverlayConfig getHybridOverlayConfig();
  public HybridOverlayConfig buildHybridOverlayConfig();
  public A withHybridOverlayConfig(HybridOverlayConfig hybridOverlayConfig);
  public Boolean hasHybridOverlayConfig();
  public OVNKubernetesConfigFluent.HybridOverlayConfigNested<A> withNewHybridOverlayConfig();
  public OVNKubernetesConfigFluent.HybridOverlayConfigNested<A> withNewHybridOverlayConfigLike(HybridOverlayConfig item);
  public OVNKubernetesConfigFluent.HybridOverlayConfigNested<A> editHybridOverlayConfig();
  public OVNKubernetesConfigFluent.HybridOverlayConfigNested<A> editOrNewHybridOverlayConfig();
  public OVNKubernetesConfigFluent.HybridOverlayConfigNested<A> editOrNewHybridOverlayConfigLike(HybridOverlayConfig item);
  
  /**
   * This method has been deprecated, please use method buildIpsecConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public IPsecConfig getIpsecConfig();
  public IPsecConfig buildIpsecConfig();
  public A withIpsecConfig(IPsecConfig ipsecConfig);
  public Boolean hasIpsecConfig();
  public OVNKubernetesConfigFluent.IpsecConfigNested<A> withNewIpsecConfig();
  public OVNKubernetesConfigFluent.IpsecConfigNested<A> withNewIpsecConfigLike(IPsecConfig item);
  public OVNKubernetesConfigFluent.IpsecConfigNested<A> editIpsecConfig();
  public OVNKubernetesConfigFluent.IpsecConfigNested<A> editOrNewIpsecConfig();
  public OVNKubernetesConfigFluent.IpsecConfigNested<A> editOrNewIpsecConfigLike(IPsecConfig item);
  public Integer getMtu();
  public A withMtu(Integer mtu);
  public Boolean hasMtu();
  
  /**
   * This method has been deprecated, please use method buildPolicyAuditConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public PolicyAuditConfig getPolicyAuditConfig();
  public PolicyAuditConfig buildPolicyAuditConfig();
  public A withPolicyAuditConfig(PolicyAuditConfig policyAuditConfig);
  public Boolean hasPolicyAuditConfig();
  public A withNewPolicyAuditConfig(String destination,Integer maxFileSize,Integer rateLimit,String syslogFacility);
  public OVNKubernetesConfigFluent.PolicyAuditConfigNested<A> withNewPolicyAuditConfig();
  public OVNKubernetesConfigFluent.PolicyAuditConfigNested<A> withNewPolicyAuditConfigLike(PolicyAuditConfig item);
  public OVNKubernetesConfigFluent.PolicyAuditConfigNested<A> editPolicyAuditConfig();
  public OVNKubernetesConfigFluent.PolicyAuditConfigNested<A> editOrNewPolicyAuditConfig();
  public OVNKubernetesConfigFluent.PolicyAuditConfigNested<A> editOrNewPolicyAuditConfigLike(PolicyAuditConfig item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface HybridOverlayConfigNested<N> extends Nested<N>,HybridOverlayConfigFluent<OVNKubernetesConfigFluent.HybridOverlayConfigNested<N>>{
    public N and();
    public N endHybridOverlayConfig();
    
  }
  public interface IpsecConfigNested<N> extends Nested<N>,IPsecConfigFluent<OVNKubernetesConfigFluent.IpsecConfigNested<N>>{
    public N and();
    public N endIpsecConfig();
    
  }
  public interface PolicyAuditConfigNested<N> extends Nested<N>,PolicyAuditConfigFluent<OVNKubernetesConfigFluent.PolicyAuditConfigNested<N>>{
    public N and();
    public N endPolicyAuditConfig();
    
  }
  
}
